==> ocp-common-3.0.0-20190325.020639-39-sources.jar: com/efuture/ocp/common/util/MapUtils.java <==
package com.efuture.ocp.common.util;

import java.math.BigDecimal;
import java.util.Map;

public class MapUtils {

	public static String getString(Map map, String key, String defval, boolean check) {
		try {
			if (map.containsKey(key) && map.get(key) != null) {
				return map.get(key).toString();
			} else {
				if (check)
					throw new Exception("Key " + key + " in Map is Null");
				else
					return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static String getString(Map map, String key, String defval) {
		return getString(map, key, defval, false);
	}

	public static String getString(Map map, String key) {
		return getString(map, key, "");
	}

	public static double getDouble(Map map, String key, double defval) {
		try {
			if (map.containsKey(key) && map.get(key) != null) {
				return Double.parseDouble(map.get(key).toString());
			} else {
				return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static double getDouble(Map map, String key) {
		return getDouble(map, key, 0);
	}

	public static int getInteger(Map map, String key, int defval) {
		try {
			if (map.containsKey(key) && map.get(key) != null) {
				return Integer.parseInt(map.get(key).toString());
			} else {
				return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static int getInteger(Map map, String key) {
		return getInteger(map, key, 0);
	}
	
	public static long getLongValue(Map map, String key, long defval) {
		try {
			if (map.containsKey(key) && map.get(key) != null) {
				return Long.parseLong(map.get(key).toString());
			} else {
				return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static long getLongValue(Map map, String key) {
		return getLongValue(map, key, 0L);
	}
	

	public static BigDecimal getBigDecimal(Map map, String key, BigDecimal defval) {
		try {
			if (map.containsKey(key) && map.get(key) != null) {
				//return BigDecimal.valueOf(Double.valueOf(map.get(key).toString()));
				return new BigDecimal(map.get(key).toString());
			} else {
				return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static BigDecimal getBigDecimal(Map map, String key) {
		return getBigDecimal(map, key, new BigDecimal(0));
	}
}

==> ocp-common-5.0.0-20210622.032615-46-sources.jar: com/efuture/ocp/common/util/MapUtils.java <==
package com.efuture.ocp.common.util;

import org.springframework.util.StringUtils;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

public class MapUtils {

	public static String getString(Map map, String key, String defval, boolean check) {
		try {
			if (map != null && map.containsKey(key) && map.get(key) != null) {
				return map.get(key).toString();
			} else {
				if (check)
					throw new Exception("Key " + key + " in Map is Null");
				else
					return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static String getString(Map map, String key, String defval) {
		return getString(map, key, defval, false);
	}

	public static String getString(Map map, String key) {
		return getString(map, key, "");
	}

	public static double getDouble(Map map, String key, double defval) {
		try {
			if (map != null && map.containsKey(key) && map.get(key) != null) {
				return Double.parseDouble(map.get(key).toString());
			} else {
				return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static double getDouble(Map map, String key) {
		return getDouble(map, key, 0);
	}

	public static int getInteger(Map map, String key, int defval) {
		try {
			if (map != null && map.containsKey(key) && map.get(key) != null) {
				return Integer.parseInt(map.get(key).toString());
			} else {
				return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static int getInteger(Map map, String key) {
		return getInteger(map, key, 0);
	}
	
	public static long getLongValue(Map map, String key, long defval) {
		try {
			if (map != null && map.containsKey(key) && map.get(key) != null) {
				return Long.parseLong(map.get(key).toString());
			} else {
				return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static long getLongValue(Map map, String key) {
		return getLongValue(map, key, 0L);
	}
	

	public static BigDecimal getBigDecimal(Map map, String key, BigDecimal defval) {
		try {
			if (map != null && map.containsKey(key) && map.get(key) != null) {
				//return BigDecimal.valueOf(Double.valueOf(map.get(key).toString()));
				return new BigDecimal(map.get(key).toString());
			} else {
				return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static BigDecimal getBigDecimal(Map map, String key) {
		return getBigDecimal(map, key, new BigDecimal(0));
	}

	public static Date getDate(Map map, String key, Date defval) {
		try {
			if (map != null && map.containsKey(key) && map.get(key) != null) {
				SimpleDateFormat sdf = new SimpleDateFormat( "yyyy-MM-dd" );
				try
				{
					return sdf.parse(getString(map, key));
				}
				catch(Exception ex)
				{
					try
					{
						return sdf.parse( sdf.format( defval ) );
					}
					catch(Exception e)
					{
						return null;
					}
				}
			} else {
				return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static Date getDate(Map map, String key) {
		return getDate(map, key, DateUtils.getFirstDay());
	}

	public static Date getDateTime(Map map, String key, Date defval) {
		try {
			if (map != null && map.containsKey(key) && map.get(key) != null) {
				try
				{
					SimpleDateFormat sdf = new SimpleDateFormat( "yyyy-MM-dd HH:mm:ss" );
					return sdf.parse(getString(map, key));
				}
				catch(Exception ex)
				{
					return defval;
				}
			} else {
				return defval;
			}
		} catch (Exception ex) {
			return defval;
		}
	}

	public static Date getDateTime(Map map, String key) {
		return getDateTime(map, key, DateUtils.getFirstDay());
	}


}
